package viewModels
{
    /**
     * Interface for any presentation model that is to be used
     * with the MainView view.
     */
    public interface IMainViewModel extends IViewModel
    {
        /**
         * The title to be displayed for the application.
         */
        function get title():String;

        [Bindable("countChanged")]
        /**
         * The global count.
         */
        function get count():int;

        /**
         * Indicates whether it is possible to delete a counter.
         */
        function get canDeleteCounter():Boolean;

        /**
         * The label to display on the countdown toggle button.
         */
        function get toggleCountdownLabel():String;

        /**
         * The counters to be used.
         */
        function get counters():Array;

        /**
         * Increases the global count.
         */
        function increaseCount():void;

        /**
         * Decreases the global count.
         */
        function decreaseCount():void;

        /**
         * Adds an additional counter.
         */
        function addCounter():void;

        /**
         * Removes the last counter.
         */
        function deleteCounter():void;

        /**
         * Stops/starts the global countdown.
         */
        function toggleCountdown():void;
    }
}