package viewModels
{
    import events.CountEvent;

    import flexunit.framework.Assert;

    import mx.collections.IList;

    import org.flexunit.asserts.assertEquals;
    import org.flexunit.asserts.assertFalse;
    import org.flexunit.asserts.assertNotNull;
    import org.flexunit.asserts.assertTrue;

    import utils.TestEventDispatcher;

    public class MainViewModelTest
    {
        [Test]
        public function testTitle():void
        {
            var viewModel:MainViewModel = new MainViewModel(null);
            assertNotNull("title", viewModel.title);
        }

        [Test]
        public function testToggleCountdownLabel():void
        {
            var viewModel:MainViewModel = new MainViewModel(null);
            assertNotNull("toggle countdown label", viewModel.toggleCountdownLabel);
        }

        [Test]
        public function testCount():void
        {
            var viewModel:MainViewModel = new MainViewModel(null);
            assertEquals("0 initial count", 0, viewModel.count);

            var expected:int = 5;
            viewModel.count = expected;
            assertEquals("count", expected, viewModel.count);
        }

        [Test]
        public function testIncreaseCount():void
        {
            var dispatcher:TestEventDispatcher = new TestEventDispatcher();
            var viewModel:MainViewModel = new MainViewModel(dispatcher);

            var expectedCount:int = viewModel.count + 1;
            viewModel.increaseCount();
            assertEquals("count increased", expectedCount, viewModel.count);
            var dispatchEvents:IList = dispatcher.eventsForType(CountEvent.GLOBAL_UPDATE);
            assertEquals("1 global count update event", 1, dispatchEvents.length);
            assertEquals("event indicates count", expectedCount, CountEvent(dispatchEvents[0]).newCount);
        }

        [Test]
        public function testDecreaseCount():void
        {
            var dispatcher:TestEventDispatcher = new TestEventDispatcher();
            var viewModel:MainViewModel = new MainViewModel(dispatcher);

            var expectedCount:int = viewModel.count - 1;
            viewModel.decreaseCount();
            assertEquals("count decreased", expectedCount, viewModel.count);
            var dispatchEvents:IList = dispatcher.eventsForType(CountEvent.GLOBAL_UPDATE);
            assertEquals("1 global count update event", 1, dispatchEvents.length);
            assertEquals("event indicates count", expectedCount, CountEvent(dispatchEvents[0]).newCount);
        }

        [Test]
        public function testAddDeleteCounter():void
        {
            var viewModel:MainViewModel = new MainViewModel(null);
            assertEquals("initially no counters", 0, viewModel.counters.length);
            assertFalse("cannot delete counter", viewModel.canDeleteCounter);

            // doesn't die trying to delete non-existent counters
            viewModel.deleteCounter();
            assertEquals("no counters", 0, viewModel.counters.length);
            assertFalse("cannot delete counter", viewModel.canDeleteCounter);

            // add a counter
            viewModel.addCounter();
            assertEquals("1 counter after add", 1, viewModel.counters.length);
            assertTrue("can delete counter", viewModel.canDeleteCounter);

            // delete a counter
            viewModel.deleteCounter();
            assertEquals("no counters", 0, viewModel.counters.length);
            assertFalse("cannot delete counter", viewModel.canDeleteCounter);
        }
    }
}