package viewModels
{
    import events.CountEvent;

    import flexunit.framework.Assert;

    import mx.collections.IList;

    import org.flexunit.asserts.assertEquals;

    import utils.TestEventDispatcher;

    public class SubCounterViewModelTest
    {
        [Test]
        public function testCount():void
        {
            var viewModel:SubCounterViewModel = new SubCounterViewModel(null);
            assertEquals("0 initial count", 0, viewModel.count);

            var expected:int = 13;
            viewModel.count = expected;
            assertEquals("count", expected, viewModel.count);
        }

        [Test]
        public function testSubTotal():void
        {
            var viewModel:SubCounterViewModel = new SubCounterViewModel(null);
            assertEquals("0 initial sub-total", 0, viewModel.subTotal);

            var expected:int = 14;
            viewModel.subTotal = expected;
            assertEquals("sub-total", expected, viewModel.subTotal);
        }

        [Test]
        public function testIncreaseCount():void
        {
            var dispatcher:TestEventDispatcher = new TestEventDispatcher();
            var viewModel:SubCounterViewModel = new SubCounterViewModel(dispatcher);

            var expectedCount:int = viewModel.count + 1;
            var expectedSubTotal:int = viewModel.subTotal + 1;
            viewModel.increaseCount();
            assertEquals("count increased", expectedCount, viewModel.count);
            assertEquals("sub-total increased", expectedSubTotal, viewModel.subTotal);
            var dispatchEvents:IList = dispatcher.eventsForType(CountEvent.LOCAL_UPDATE);
            assertEquals("1 local count update event", 1, dispatchEvents.length);
            assertEquals("event indicates sub-total", expectedSubTotal, CountEvent(dispatchEvents[0]).newCount);
        }

        [Test]
        public function testDecreaseCount():void
        {
            var dispatcher:TestEventDispatcher = new TestEventDispatcher();
            var viewModel:SubCounterViewModel = new SubCounterViewModel(dispatcher);

            var expectedCount:int = viewModel.count - 1;
            var expectedSubTotal:int = viewModel.subTotal - 1;
            viewModel.decreaseCount();
            assertEquals("count decreased", expectedCount, viewModel.count);
            assertEquals("sub-total decreased", expectedSubTotal, viewModel.subTotal);
            var dispatchEvents:IList = dispatcher.eventsForType(CountEvent.LOCAL_UPDATE);
            assertEquals("1 local count update event", 1, dispatchEvents.length);
            assertEquals("event indicates sub-total", expectedSubTotal, CountEvent(dispatchEvents[0]).newCount);
        }
    }
}